@@ -1,9 +1,7 @@
 library(jsonlite)
 library(dplyr)
-library(lubridate)
 library(purrr)
 library(testthat)
-library(curl)
 # options(digits = 22)
 
 # Note that this .R script doesn't know about functions in priceR
@@ -16,15 +14,15 @@ library(curl)
 
 
 
-# Assign these variables once
-country <- "AU"
-inflation_dataframe <- retrieve_inflation_data(country)
-countries_dataframe <- show_countries()
-
-
-# Required for some error messages
-available_inflation_data <- inflation_dataframe %>% na.omit
-
-price <- 10
-
+# # Assign these variables once
+# country <- "AU"
+# inflation_dataframe <- retrieve_inflation_data(country)
+# countries_dataframe <- show_countries()
+#
+#
+# # Required for some error messages
+# available_inflation_data <- inflation_dataframe %>% na.omit
+#
+# price <- 10
+#
 
